#! /bin/sh

# $Id: qtree.sh,v 1.8 1996-05-05 17:39:17+10 jeremy Exp $

# Called by qtree.
# Some of these commands are run quietly. For these commands,
#  any output from the command is captured by qtree and displayed
#  as an error message.
# Other commands are run verbosely (and possibly interactively).
#  For these commands, qtree clears the screen before running the
#  command. After the command completes, qtree waits for the user
#  to press a key, then redisplays its screen.

# Parameters:
# $1=command
# $2=selected pathname, or name of file containing list of tagged files
# $3=destination pathname (if applicable)
# $4=archive name (if applicable) (not implemented)

# Return values:
# 0=command completed OK
# 1=error. For quiet commands, output from the command (if any)
#  will be displayed by qtree as an error msg.


case $1 in

# "internal" command for efficient calling of cp/mv using xargs
# changes order of params so dest precedes src(s)

	destsrc)
		cmd=$2
		opt=$3
		dest=$4
		shift 4
		for x in $@; do
			src="$src $x"
		done
		$cmd $opt $src $dest
		exit
		;;
	
## quiet commands
	
	delete)
		rm -f $2
		exit $?
		;;
	
	copy)
		cp -f $2 $3
		exit $?
		;;
		
	move)
		mv -f $2 $3
		exit $?
		;;
		
## verbose commands
		
	view)
		case $2 in
			*.tar|*.pax)
				pax -v <$2 | less
				;;
			*.tar.F|*.pax.F)
				melt <$2 | pax -v | less
				;;
			*.tar.gz|*.pax.gz)
				gzip -cd <$2 | pax -v | less
				;;
			*.bmp|*.jpg|*.gif|*.pcx)
				pv $2;
				;;
			*)
				vedit -b $2
				;;
		esac
		exit $?
		;;
	
	edit)
		vedit $2
		exit $?
		;;
	
	delete_tagged)
		# the -n50 option is necessary due to a bug in Ver 4.22 xargs
		xargs -n50 <$2 rm -vf
		exit $?
		;;
		
	copy_tagged)
		xargs -n50 <$2 $0 destsrc cp -fv $3
		exit $?
		;;
		
	icopy_tagged)
		xargs -n50 <$2 $0 destsrc cp -iv $3
		exit $?
		;;
		
	move_tagged)
		xargs -n50 <$2 $0 destsrc mv -v $3
		exit $?
		;;
		
	imove_tagged)
		# "mv -vi" prompts for confirmation without telling you
		# which file it is up to!
		for i in `cat $2`; do
			echo Moving $i to $3
			mv -i $i $3
		done
		exit $?
		;;
		
	altcopy_tagged)
		# could also use pax -rw
		for i in `cat $2`; do
			cp -fcv $i $3/$i
		done
		exit $?
		;;
		
	ialtcopy_tagged)
		for i in `cat $2`; do
			cp -icv $i $3/$i
		done
		exit $?
		;;
		
	archive_tagged)
		case $3 in
			*.tar|*.pax)
				pax -wv <$2 >$3
				;;
			*.tar.F|*.pax.F)
				pax -wv <$2 | freeze >$3
				;;
			*.tar.gz|*.pax.gz)
				pax -wv <$2 | gzip -c >$3
				;;
			*)
				echo Unknown archive format!
				exit 1
				;;
		esac
		exit $?
		;;
		
	*)
		echo \'$1\' function not implemented
		exit 1
		;;

esac

